# CNN runner
Software package for CNN implementation

## Authors
- [xabarov](https://github.com/xabarov)

## Installation
Install cnn_runner with pip
```bash
  pip install cnn_runner
```


## Requirements
* matplotlib>=3.5






